window.Gleam.initSearch([{"doc":"worm","title":"worm","content":"# worm 🪱\n\n[![Package Version](https://img.shields.io/hexpm/v/worm)](https://hex.pm/packages/worm)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/worm/)\n\n```sh\ngleam add worm\n```\n```gleam\nimport gleam/regex\nimport worm\n\ntype RegexCache {\n  RegexCache(greeting: regex.Regex, name: regex.Regex)\n}\n\nfn regexes() -&gt; RegexCache {\n  use &lt;- worm.persist()\n  let assert Ok(greeting) = regex.from_string(&quot;^\\\\w+&quot;)\n  let assert Ok(name) = regex.from_string(&quot;\\\\w+$&quot;)\n  RegexCache(greeting, name)\n}\n\npub fn main() {\n  let RegexCache(greeting: initial, ..) = regexes()\n\n  &quot;Hello, Gleam!&quot;\n  |&gt; regex.scan(with: initial) // [regex.Match(&quot;Hello&quot;, [])]\n\n  Nil\n}\n```\n\nWhile this library was initial concieved of as a cache for regex compilation, it can be used for any deterministic calculation which you only want to run once and reuse many times.\n\nPlease read the documentation before using this library as it is not the best solution for many situations. API documentation can be found at &lt;https://hexdocs.pm/worm/worm.html&gt;.\n\n[persistent_term]: https://www.erlang.org/doc/apps/erts/persistent_term.html\n","url":"index.html"},{"doc":"worm","title":"persist","content":"pub fn persist(generator: fn() -&gt; a) -&gt; a\n Persist the result of a callback.\n\n The generator function is expected to be deterministic and pure. Your generator function will be called\n at least once, but may be called more than once due to race conditions during the initial filling of\n the cache. After the cache is filled, your generator function will never be called again. If your generator\n produces side effects then those side effects will be extremely unreliable.\n\n ## Examples\n\n \n pub type RegexCache {\n   RegexCache(greeting: regex.Regex, name: regex.Regex)\n }\n\n fn regexes() -&gt; RegexCache {\n   use &lt;- worm.persist()\n   let assert Ok(greeting) = regex.from_string(&quot;^\\\\w+&quot;)\n   let assert Ok(name) = regex.from_string(&quot;\\\\w+$&quot;)\n   RegexCache(greeting, name)\n }\n \nSynonyms:\nworm.persist\nworm persist","url":"worm.html#persist"},{"doc":"worm","title":"worm","content":" Worm is used to persist the results of a function call indefinitely in a write-once, read-many cache.\n\n ## Usage\n\n Worm is a write-once, read-many cache designed to be used for caching deterministic values. Good examples\n of things to use this for are regex compilation and lookup tables - things that are calculated once and\n never change.\n\n ## Limitations\n\n * There is intentionally no way to flush the cache and any data stored in the cache is stored in memory in\n   a way that will never be garbage collected. Updating or removing cache elements would trigger a global\n   GC pass and hence would be a very expensive operation.\n\n * If you are using `worm` in a library then it is recommended to stick to one big cache for your library\n   wherever possible. The [`persistent_term`](https://www.erlang.org/doc/apps/erts/persistent_term.html)\n   package used to facilitate the cache on the Erlang target gets slower the more individual terms are\n   stored. Hence, a single large object stored in a single term and destructured in Gleam is the preferred\n   approach as much as reasonable.\n\n * Erlang has a 1GB limit on storage in this cache by default. This is [configurable when starting an application](https://www.erlang.org/doc/apps/erts/persistent_term.html#module-storing-huge-persistent-terms),\n   however beware of this limit when using `worm` in a library. Caching large amounts of data in `worm` is\n   probably the wrong solution.","url":"worm.html"}]);